# Copyright information in version.rb
#
module Hov
  # environment variables. Modify .env file to use
  ENV_VARS = %w(HOV_OVERWRITE_LOGS
                HOV_REMOTE_LOGGER).freeze

  ENV_FILE = '.hov/.env'.freeze
  ENV_TEMPLATE = 'lib/hov/templates/.env'.freeze

  # Log defaults
  DEFAULT_LOG_LEVEL = Logger::INFO
  LOG_FILE = '.hov/logs/hov.log'.freeze

  # instantiates a global log definition - smells but simple
  class Config
    attr_accessor :stdout_log, :local_log, :remote_log
    attr_accessor :write_log

    def initialize
      local_environment # create default .hov/.env if it does not already exist
      @stdout_log     = Hov::Logging.stdout_logger
      @local_log      = Hov::Logging.file_logger
      @remote_log     = Hov::Logging.remote_logger
      @write_log      = Hov::Logging::MultiLogger.new(@local_log, @remote_log)
    end

    private

    def local_environment
      unless File.exist?(Hov::ENV_FILE)
        FileUtils.mkdir_p(File.dirname(Hov::ENV_FILE))
        FileUtils.cp(Hov.source_root + Hov::ENV_TEMPLATE, Hov::ENV_FILE)
      end
      Dotenv.load(Hov::ENV_FILE)
    end
  end
end
