# Copyright information in version.rb
#
module Hov
  # misc methods and classes
  module Logging
    # send log info to both console and log file
    class MultiLogger
      def initialize(*targets)
        @targets = targets.compact
      end

      %w(log debug info warn error fatal unknown).each do |level|
        define_method(level) { |*args| @targets.map { |target| target.send(level, *args) } }
      end
    end

    def self.stdout_logger
      # Log level and format for stdout message
      log = Logger.new($stdout)
      log.level = Hov::DEFAULT_LOG_LEVEL
      log.progname = Hov::APP_NAME
      log.formatter = proc { |_severity, _datetime, _progname, msg| "hov: #{msg}\n" }
      log
    end

    def self.file_logger
      mode = ENV['HOV_OVERWRITE_LOGS'].to_s.casecmp('true') == 0 ? 'wb' : 'ab'
      FileUtils.mkdir_p(File.dirname(Hov::LOG_FILE))
      file = File.open(File.expand_path(Hov::LOG_FILE), mode)
      file.sync = true
      log = Logger.new(file)
      log.level = Hov::DEFAULT_LOG_LEVEL
      log.progname = Hov::APP_NAME
      log
    end

    def self.remote_logger
      if ENV['HOV_REMOTE_LOGGER']
        log = Hov::Logging.send(ENV['HOV_REMOTE_LOGGER'])
        log.level = Hov::DEFAULT_LOG_LEVEL
        log.progname = Hov::APP_NAME
      end
      log
    end

    def self.papertrail
      require 'remote_syslog_logger'
      RemoteSyslogLogger.new(ENV['HOV_PAPERTRAIL_URL'], ENV['HOV_PAPERTRAIL_PORT'])
    end
  end
end
